/* eslint @typescript-eslint/no-var-requires: "off" */
const { generateTSFiles } = require('swagger-ts-generator');

// const config = {
//    file: __dirname + '\\swagger.json'
// };

generateTSFiles(
  // Better read from URL http://localhost:8080/v2/api-docs
  {
    swagger: '2.0',
    info: {
      description: 'gitsearch API documentation',
      version: '0.1.0',
      title: 'gitsearch API',
      contact: {},
      license: { name: 'unlicensed' },
    },
    host: 'localhost:8080',
    basePath: '/',
    tags: [
      { name: 'account-resource', description: 'Account Resource' },
      { name: 'git-files-resource', description: 'Git Files Resource' },
      { name: 'search-resource', description: 'Search Resource' },
      { name: 'user-jwt-controller', description: 'User JWT Controller' },
      { name: 'user-resource', description: 'User Resource' },
    ],
    schemes: ['http', 'https'],
    paths: {
      '/api/_search/git-files/aggregation': {
        get: {
          tags: ['git-files-resource'],
          summary: 'gitFilesAggregation',
          operationId: 'gitFilesAggregationUsingGET',
          produces: ['*/*'],
          parameters: [{ name: 'query', in: 'query', description: 'query', required: true, type: 'string' }],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/GitFilesAggregationDTO' } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/_search/git-files/page-details': {
        get: {
          tags: ['git-files-resource'],
          summary: 'gitFilesPageDetails',
          operationId: 'gitFilesPageDetailsUsingGET',
          produces: ['*/*'],
          parameters: [
            { name: 'fulltextQuery', in: 'query', description: 'fulltextQuery', required: true, type: 'string' },
            { name: 'metadataAuthor', in: 'query', description: 'metadataAuthor', required: true, type: 'string' },
            { name: 'metadataKeywords', in: 'query', description: 'metadataKeywords', required: true, type: 'string' },
            { name: 'metadataLicense', in: 'query', description: 'metadataLicense', required: true, type: 'string' },
            { name: 'metadataNaturalLanguage', in: 'query', description: 'metadataNaturalLanguage', required: true, type: 'string' },
            {
              name: 'metadataProgrammingLanguage',
              in: 'query',
              description: 'metadataProgrammingLanguage',
              required: true,
              type: 'string',
            },
            { name: 'page', in: 'query', description: 'page', required: true, type: 'integer', format: 'int32' },
            { name: 'pageSize', in: 'query', description: 'pageSize', required: true, type: 'integer', format: 'int32' },
            {
              name: 'selectedFileFormat',
              in: 'query',
              description: 'selectedFileFormat',
              required: true,
              type: 'array',
              items: { type: 'string' },
              collectionFormat: 'multi',
            },
            {
              name: 'selectedRepository',
              in: 'query',
              description: 'selectedRepository',
              required: true,
              type: 'array',
              items: { type: 'string' },
              collectionFormat: 'multi',
            },
            {
              name: 'selectedUniversity',
              in: 'query',
              description: 'selectedUniversity',
              required: true,
              type: 'array',
              items: { type: 'string' },
              collectionFormat: 'multi',
            },
          ],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/GitFilesPageDetailsDTO' } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/_search/users/{query}': {
        get: {
          tags: ['user-resource'],
          summary: 'search',
          operationId: 'searchUsingGET',
          produces: ['*/*'],
          parameters: [{ name: 'query', in: 'path', description: 'query', required: true, type: 'string' }],
          responses: {
            200: { description: 'OK', schema: { type: 'array', items: { $ref: '#/definitions/User' } } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/account': {
        get: {
          tags: ['account-resource'],
          summary: 'getAccount',
          operationId: 'getAccountUsingGET',
          produces: ['*/*'],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/UserDTO' } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
        post: {
          tags: ['account-resource'],
          summary: 'saveAccount',
          operationId: 'saveAccountUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [{ in: 'body', name: 'userDTO', description: 'userDTO', required: true, schema: { $ref: '#/definitions/UserDTO' } }],
          responses: {
            200: { description: 'OK' },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/account/change-password': {
        post: {
          tags: ['account-resource'],
          summary: 'changePassword',
          operationId: 'changePasswordUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [
            {
              in: 'body',
              name: 'passwordChangeDto',
              description: 'passwordChangeDto',
              required: true,
              schema: { $ref: '#/definitions/PasswordChangeDTO' },
            },
          ],
          responses: {
            200: { description: 'OK' },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/account/reset-password/finish': {
        post: {
          tags: ['account-resource'],
          summary: 'finishPasswordReset',
          operationId: 'finishPasswordResetUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [
            {
              in: 'body',
              name: 'keyAndPassword',
              description: 'keyAndPassword',
              required: true,
              schema: { $ref: '#/definitions/KeyAndPasswordVM' },
            },
          ],
          responses: {
            200: { description: 'OK' },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/account/reset-password/init': {
        post: {
          tags: ['account-resource'],
          summary: 'requestPasswordReset',
          operationId: 'requestPasswordResetUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [{ in: 'body', name: 'mail', description: 'mail', required: true, schema: { type: 'string' } }],
          responses: {
            200: { description: 'OK' },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/activate': {
        get: {
          tags: ['account-resource'],
          summary: 'activateAccount',
          operationId: 'activateAccountUsingGET',
          produces: ['*/*'],
          parameters: [{ name: 'key', in: 'query', description: 'key', required: true, type: 'string' }],
          responses: {
            200: { description: 'OK' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/authenticate': {
        get: {
          tags: ['account-resource'],
          summary: 'isAuthenticated',
          operationId: 'isAuthenticatedUsingGET',
          produces: ['*/*'],
          responses: {
            200: { description: 'OK', schema: { type: 'string' } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
        post: {
          tags: ['user-jwt-controller'],
          summary: 'authorize',
          operationId: 'authorizeUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [{ in: 'body', name: 'loginVM', description: 'loginVM', required: true, schema: { $ref: '#/definitions/LoginVM' } }],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/JWTToken' } },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/register': {
        post: {
          tags: ['account-resource'],
          summary: 'registerAccount',
          operationId: 'registerAccountUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [
            {
              in: 'body',
              name: 'managedUserVM',
              description: 'managedUserVM',
              required: true,
              schema: { $ref: '#/definitions/ManagedUserVM' },
            },
          ],
          responses: {
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/search/page-details': {
        post: {
          tags: ['search-resource'],
          summary: 'searchPageDetails',
          operationId: 'searchPageDetailsUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [
            { in: 'body', name: 'query', description: 'query', required: true, schema: { $ref: '#/definitions/SearchInputDTO' } },
          ],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/SearchResultsDTO' } },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/users': {
        get: {
          tags: ['user-resource'],
          summary: 'getAllUsers',
          operationId: 'getAllUsersUsingGET',
          produces: ['*/*'],
          parameters: [
            {
              name: 'page',
              in: 'query',
              description: 'Page number of the requested page',
              required: false,
              type: 'integer',
              format: 'int32',
            },
            { name: 'size', in: 'query', description: 'Size of a page', required: false, type: 'integer', format: 'int32' },
            {
              name: 'sort',
              in: 'query',
              description:
                'Sorting criteria in the format: property(,asc|desc). Default sort order is ascending. Multiple sort criteria are supported.',
              required: false,
              type: 'array',
              items: { type: 'string' },
              collectionFormat: 'multi',
            },
          ],
          responses: {
            200: { description: 'OK', schema: { type: 'array', items: { $ref: '#/definitions/UserDTO' } } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
        post: {
          tags: ['user-resource'],
          summary: 'createUser',
          operationId: 'createUserUsingPOST',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [{ in: 'body', name: 'userDTO', description: 'userDTO', required: true, schema: { $ref: '#/definitions/UserDTO' } }],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/User' } },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
        put: {
          tags: ['user-resource'],
          summary: 'updateUser',
          operationId: 'updateUserUsingPUT',
          consumes: ['application/json'],
          produces: ['*/*'],
          parameters: [{ in: 'body', name: 'userDTO', description: 'userDTO', required: true, schema: { $ref: '#/definitions/UserDTO' } }],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/UserDTO' } },
            201: { description: 'Created' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/users/authorities': {
        get: {
          tags: ['user-resource'],
          summary: 'getAuthorities',
          operationId: 'getAuthoritiesUsingGET',
          produces: ['*/*'],
          responses: {
            200: { description: 'OK', schema: { type: 'array', items: { type: 'string' } } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
      },
      '/api/users/{login:^(?>[a-zA-Z0-9!$&*+=?^_`{|}~.-]+@[a-zA-Z0-9-]+(?:\\.[a-zA-Z0-9-]+)*)|(?>[_.@A-Za-z0-9-]+)$}': {
        get: {
          tags: ['user-resource'],
          summary: 'getUser',
          operationId: 'getUserUsingGET',
          produces: ['*/*'],
          parameters: [{ name: 'login', in: 'path', description: 'login', required: true, type: 'string' }],
          responses: {
            200: { description: 'OK', schema: { $ref: '#/definitions/UserDTO' } },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
            404: { description: 'Not Found' },
          },
          deprecated: false,
        },
        delete: {
          tags: ['user-resource'],
          summary: 'deleteUser',
          operationId: 'deleteUserUsingDELETE',
          produces: ['*/*'],
          parameters: [{ name: 'login', in: 'path', description: 'login', required: true, type: 'string' }],
          responses: {
            200: { description: 'OK' },
            204: { description: 'No Content' },
            401: { description: 'Unauthorized' },
            403: { description: 'Forbidden' },
          },
          deprecated: false,
        },
      },
    },
    definitions: {
      ExerciseType: { type: 'object', title: 'ExerciseType' },
      FragmentDTO: {
        type: 'object',
        properties: { firstLineNumber: { type: 'integer', format: 'int32' }, fragment: { type: 'string' } },
        title: 'FragmentDTO',
      },
      FrequencyDTOOfstring: {
        type: 'object',
        properties: { key: { type: 'string' }, value: { type: 'integer', format: 'int64' } },
        title: 'FrequencyDTOOfstring',
      },
      GitFilesAggregationDTO: {
        type: 'object',
        properties: {
          fileFormat: { type: 'array', items: { $ref: '#/definitions/FrequencyDTOOfstring' } },
          repositories: { type: 'array', items: { $ref: '#/definitions/FrequencyDTOOfstring' } },
          university: { type: 'array', items: { $ref: '#/definitions/FrequencyDTOOfstring' } },
        },
        title: 'GitFilesAggregationDTO',
      },
      GitFilesDTO: {
        type: 'object',
        properties: {
          content: { type: 'string' },
          fileExtension: { type: 'string' },
          fileFormat: { type: 'string' },
          fileName: { type: 'string' },
          filePath: { type: 'string' },
          fragment: { $ref: '#/definitions/FragmentDTO' },
          gitUrl: { type: 'string' },
          repository: { type: 'string' },
          subGroup: { type: 'string' },
          url: { type: 'string' },
        },
        title: 'GitFilesDTO',
      },
      GitFilesPageDetailsDTO: {
        type: 'object',
        properties: {
          gitFiles: { type: 'array', items: { $ref: '#/definitions/GitFilesDTO' } },
          hitCount: { type: 'integer', format: 'int64' },
        },
        title: 'GitFilesPageDetailsDTO',
      },
      JWTToken: { type: 'object', properties: { id_token: { type: 'string' } }, title: 'JWTToken' },
      KeyAndPasswordVM: {
        type: 'object',
        properties: { key: { type: 'string' }, newPassword: { type: 'string' } },
        title: 'KeyAndPasswordVM',
      },
      LoginVM: {
        type: 'object',
        required: ['password', 'username'],
        properties: {
          password: { type: 'string', minLength: 4, maxLength: 100 },
          rememberMe: { type: 'boolean' },
          username: { type: 'string', minLength: 1, maxLength: 50 },
        },
        title: 'LoginVM',
      },
      ManagedUserVM: {
        type: 'object',
        properties: {
          activated: { type: 'boolean' },
          authorities: { type: 'array', items: { type: 'string' } },
          createdBy: { type: 'string' },
          createdDate: { type: 'string', format: 'date-time' },
          email: { type: 'string', minLength: 5, maxLength: 254 },
          firstName: { type: 'string', minLength: 0, maxLength: 50 },
          id: { type: 'integer', format: 'int64' },
          imageUrl: { type: 'string', minLength: 0, maxLength: 256 },
          langKey: { type: 'string', minLength: 2, maxLength: 10 },
          lastModifiedBy: { type: 'string' },
          lastModifiedDate: { type: 'string', format: 'date-time' },
          lastName: { type: 'string', minLength: 0, maxLength: 50 },
          login: {
            type: 'string',
            minLength: 1,
            maxLength: 50,
            pattern: '^(?>[a-zA-Z0-9!$&*+=?^_`{|}~.-]+@[a-zA-Z0-9-]+(?:\\.[a-zA-Z0-9-]+)*)|(?>[_.@A-Za-z0-9-]+)$',
          },
          password: { type: 'string', minLength: 4, maxLength: 100 },
        },
        title: 'ManagedUserVM',
      },
      PasswordChangeDTO: {
        type: 'object',
        properties: { currentPassword: { type: 'string' }, newPassword: { type: 'string' } },
        title: 'PasswordChangeDTO',
      },
      Person: {
        type: 'object',
        properties: { affiliation: { type: 'string' }, email: { type: 'string' }, name: { type: 'string' } },
        title: 'Person',
      },
      SearchInputDTO: {
        type: 'object',
        properties: {
          fulltextQuery: { type: 'string' },
          metadataAuthor: { type: 'string' },
          metadataKeywords: { type: 'string' },
          metadataLicense: { type: 'string' },
          metadataNaturalLanguage: { type: 'string' },
          metadataProgrammingLanguage: { type: 'string' },
          page: { type: 'integer', format: 'int32' },
          selectedFileFormat: { type: 'array', items: { type: 'string' } },
          selectedRepository: { type: 'array', items: { type: 'string' } },
          selectedUniversity: { type: 'array', items: { type: 'string' } },
        },
        title: 'SearchInputDTO',
      },
      SearchResultDTO: {
        type: 'object',
        properties: {
          contributor: { type: 'array', items: { $ref: '#/definitions/Person' } },
          creator: { type: 'array', items: { $ref: '#/definitions/Person' } },
          deprecated: { type: 'boolean' },
          description: { type: 'string' },
          difficulty: { type: 'string' },
          educationLevel: { type: 'string' },
          format: { type: 'string' },
          identifier: { type: 'string' },
          image: { type: 'string' },
          keyword: { type: 'array', items: { type: 'string' } },
          language: { type: 'array', items: { type: 'string' } },
          license: { type: 'string' },
          metadataVersion: { type: 'string' },
          programmingLanguage: { type: 'array', items: { type: 'string' } },
          publisher: { type: 'array', items: { $ref: '#/definitions/Person' } },
          repositoryURL: { type: 'string' },
          requires: { type: 'string' },
          source: { type: 'array', items: { type: 'string' } },
          status: { type: 'string' },
          structure: { type: 'string' },
          timeRequired: { type: 'string' },
          title: { type: 'string' },
          type: { $ref: '#/definitions/ExerciseType' },
          version: { type: 'string' },
        },
        title: 'SearchResultDTO',
      },
      SearchResultsDTO: {
        type: 'object',
        properties: {
          hitCount: { type: 'integer', format: 'int64' },
          searchResult: { type: 'array', items: { $ref: '#/definitions/SearchResultDTO' } },
        },
        title: 'SearchResultsDTO',
      },
      User: {
        type: 'object',
        required: ['activated', 'login'],
        properties: {
          activated: { type: 'boolean' },
          email: { type: 'string', minLength: 5, maxLength: 254 },
          firstName: { type: 'string', minLength: 0, maxLength: 50 },
          id: { type: 'integer', format: 'int64' },
          imageUrl: { type: 'string', minLength: 0, maxLength: 256 },
          langKey: { type: 'string', minLength: 2, maxLength: 10 },
          lastName: { type: 'string', minLength: 0, maxLength: 50 },
          login: {
            type: 'string',
            minLength: 1,
            maxLength: 50,
            pattern: '^(?>[a-zA-Z0-9!$&*+=?^_`{|}~.-]+@[a-zA-Z0-9-]+(?:\\.[a-zA-Z0-9-]+)*)|(?>[_.@A-Za-z0-9-]+)$',
          },
          resetDate: { type: 'string', format: 'date-time' },
        },
        title: 'User',
      },
      UserDTO: {
        type: 'object',
        properties: {
          activated: { type: 'boolean' },
          authorities: { type: 'array', items: { type: 'string' } },
          createdBy: { type: 'string' },
          createdDate: { type: 'string', format: 'date-time' },
          email: { type: 'string', minLength: 5, maxLength: 254 },
          firstName: { type: 'string', minLength: 0, maxLength: 50 },
          id: { type: 'integer', format: 'int64' },
          imageUrl: { type: 'string', minLength: 0, maxLength: 256 },
          langKey: { type: 'string', minLength: 2, maxLength: 10 },
          lastModifiedBy: { type: 'string' },
          lastModifiedDate: { type: 'string', format: 'date-time' },
          lastName: { type: 'string', minLength: 0, maxLength: 50 },
          login: {
            type: 'string',
            minLength: 1,
            maxLength: 50,
            pattern: '^(?>[a-zA-Z0-9!$&*+=?^_`{|}~.-]+@[a-zA-Z0-9-]+(?:\\.[a-zA-Z0-9-]+)*)|(?>[_.@A-Za-z0-9-]+)$',
          },
        },
        title: 'UserDTO',
      },
    },
  },
  {
    modelFolder: './src/main/resources/swagger-ts-generator/models',
    enumTSFile: './src/main/resources/swagger-ts-generator/enums.ts',
    // + optionally more configuration
  }
);
