import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { finalize, map } from 'rxjs/operators';

import { ISavedSearches, SavedSearches } from '../saved-searches.model';
import { SavedSearchesService } from '../service/saved-searches.service';
import { IUser } from 'app/entities/user/user.model';
import { UserService } from 'app/entities/user/user.service';

@Component({
  selector: 'jhi-saved-searches-update',
  templateUrl: './saved-searches-update.component.html',
})
export class SavedSearchesUpdateComponent implements OnInit {
  isSaving = false;

  usersSharedCollection: IUser[] = [];

  editForm = this.fb.group({
    id: [],
    name: [null, [Validators.required, Validators.maxLength(50)]],
    jsonQuery: [null, [Validators.required, Validators.maxLength(2000)]],
    user: [null, Validators.required],
  });

  constructor(
    protected savedSearchesService: SavedSearchesService,
    protected userService: UserService,
    protected activatedRoute: ActivatedRoute,
    protected fb: FormBuilder
  ) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ savedSearches }) => {
      this.updateForm(savedSearches);

      this.loadRelationshipsOptions();
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const savedSearches = this.createFromForm();
    if (savedSearches.id !== undefined) {
      this.subscribeToSaveResponse(this.savedSearchesService.update(savedSearches));
    } else {
      this.subscribeToSaveResponse(this.savedSearchesService.create(savedSearches));
    }
  }

  trackUserById(index: number, item: IUser): number {
    return item.id!;
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<ISavedSearches>>): void {
    result.pipe(finalize(() => this.onSaveFinalize())).subscribe({
      next: () => this.onSaveSuccess(),
      error: () => this.onSaveError(),
    });
  }

  protected onSaveSuccess(): void {
    this.previousState();
  }

  protected onSaveError(): void {
    // Api for inheritance.
  }

  protected onSaveFinalize(): void {
    this.isSaving = false;
  }

  protected updateForm(savedSearches: ISavedSearches): void {
    this.editForm.patchValue({
      id: savedSearches.id,
      name: savedSearches.name,
      jsonQuery: savedSearches.jsonQuery,
      user: savedSearches.user,
    });

    this.usersSharedCollection = this.userService.addUserToCollectionIfMissing(this.usersSharedCollection, savedSearches.user);
  }

  protected loadRelationshipsOptions(): void {
    this.userService
      .query()
      .pipe(map((res: HttpResponse<IUser[]>) => res.body ?? []))
      .pipe(map((users: IUser[]) => this.userService.addUserToCollectionIfMissing(users, this.editForm.get('user')!.value)))
      .subscribe((users: IUser[]) => (this.usersSharedCollection = users));
  }

  protected createFromForm(): ISavedSearches {
    return {
      ...new SavedSearches(),
      id: this.editForm.get(['id'])!.value,
      name: this.editForm.get(['name'])!.value,
      jsonQuery: this.editForm.get(['jsonQuery'])!.value,
      user: this.editForm.get(['user'])!.value,
    };
  }
}
